" Vim syntax file
" Language:    DyLOG
" Maintainers: Matteo Baldoni <baldoni@di.unito.it>
" Last Change: February 4th, 2001
" Vim syntax file based on the prolog syntax file by 
" Ralph Becket <rwab1@cam.sri.co.uk> and
" Thomas Koehler <jean-luc@picard.franken.de>

" There are two sets of highlighting in here:
" If the "prolog_highlighting_clean" variable exists, it is rather sparse.
" Otherwise you get more highlighting.

" Remove any old syntax stuff hanging around.
syn clear

" Prolog is case sensitive.
syn case match

" Very simple highlighting for comments, clause heads and
" character codes.  It respects prolog strings and atoms.

syn region   prologCComment     start=+/\*+ end=+\*/+
syn match    prologComment      +%.*+

syn match    prologCharCode     +0'\\\=.+
syn region   prologString       start=+"+ skip=+\\"+ end=+"+
syn region   prologAtom         start=+'+ skip=+\\'+ end=+'+
" Keyword for DyLOG
"syn region   prologParens       start=+(+ end=+)+  contains=prologSpecialCharacter,prologAtom,prologString,prologKeyword,prologParens
"  syn match   prologDebugParensError +"\([^"\\]\|\\.\)*$+                    
"syn region   prologClauseHead   start=+^[a-z][^(]*(+ end=+:-\|\.\|-->+

" catch errors caused by wrong parenthesis
syn region  prologSquareParen          transparent start="\[" end="\]" contains=prologParen,prologSquareParen,prologParenError,prologAtom,prologString,prologSpecialCharacter,prologNumber,prologOperator
syn match   prologSquareParenError     "\]"
hi link     prologSquareParenError     Error                                      

" catch errors caused by wrong parenthesis
syn region  prologParen          transparent start="(" end=")" contains=prologParen,prologSquareParen,prologKeywordIn,prologSquareParenError,prologAtom,prologString,prologSpecialCharacter,prologNumber,prologOperator
syn match   prologParenError     ")"
hi link     prologParenError     Error                                      


if !exists("prolog_highlighting_clean")

  " some keywords
  " some common predicates are also highlighted as keywords
  " is there a better solution?
" Keyword for DyLOG
  syn keyword prologKeyword   functionalFluent
  syn keyword prologKeyword   obs
  syn keyword prologKeyword   domain  
  syn keyword prologKeywordIn in after dyLog
  syn keyword prologKeyword   isp
  syn keyword prologKeyword   possible_if
  syn keyword prologKeyword   causes  if
  syn keyword prologKeyword   performs
  syn keyword prologKeyword   suggests  suggests_routine  where
  syn keyword prologKeyword   senses  senses_routine
  syn keyword prologKeyword   plan  exe
" Keyword for Sicstus
  syn keyword prologKeyword   use_module  library
" Keyword for Prolog
  syn keyword prologKeyword   abolish current_output  peek_code
  syn keyword prologKeyword   append  current_predicate       put_byte
  syn keyword prologKeyword   arg     current_prolog_flag     put_char
  syn keyword prologKeyword   asserta fail    put_code
  syn keyword prologKeyword   assertz findall read
  syn keyword prologKeyword   at_end_of_stream        float   read_term
  syn keyword prologKeyword   atom    flush_output    repeat
  syn keyword prologKeyword   atom_chars      functor retract
  syn keyword prologKeyword   atom_codes      get_byte        set_input
  syn keyword prologKeyword   atom_concat     get_char        set_output
  syn keyword prologKeyword   atom_length     get_code        set_prolog_flag
  syn keyword prologKeyword   atomic  halt    set_stream_position
  syn keyword prologKeyword   bagof   integer setof
  syn keyword prologKeyword   call    is      stream_property
  syn keyword prologKeyword   catch   nl      sub_atom
  syn keyword prologKeyword   char_code       nonvar  throw
  syn keyword prologKeyword   char_conversion number  true
  syn keyword prologKeyword   clause  number_chars    unify_with_occurs_check
  syn keyword prologKeyword   close   number_codes    var
  syn keyword prologKeyword   compound        once    write
  syn keyword prologKeyword   copy_term       op      write_canonical
  syn keyword prologKeyword   current_char_conversion open    write_term
  syn keyword prologKeyword   current_input   peek_byte       writeq
  syn keyword prologKeyword   current_op      peek_char

  syn match   prologOperator "=\\=\|=:=\|\\==\|=<\|==\|>=\|\\=\|\\+\|<\|>\|="
  syn match   prologAsIs     "===\|\\===\|<=\|=>"

  syn match   prologNumber            "\<[0123456789]*\>"
  syn match   prologCommentError      "\*/"
" Special character for DyLOG
  syn match   prologSpecialCharacter  "?"
  syn match   prologSpecialCharacter  "+"
  syn match   prologSpecialCharacter  "\~"
  syn match   prologSpecialCharacter  "&"
" Special character for Prolog
  syn match   prologSpecialCharacter  ";"
  syn match   prologSpecialCharacter  "!"
  syn match   prologSpecialCharacter  ":-"
  syn match   prologQuestion          "?-.*\."  contains=prologNumber


endif

syn sync ccomment maxlines=50

if !exists("did_prolog_syntax_inits")

  let did_prolog_syntax_inits = 1

  " The default methods for highlighting.  Can be overridden later

  hi link prologComment    Comment
  hi link prologCComment   Comment
  hi link prologCharCode   Special

  if exists ("prolog_highlighting_clean")

    hi link prologKeyword      Statement
    hi link prologKeywordIn    Statement
"    hi link prologClauseHead   Statement

  else

    hi link prologKeyword          Keyword
    hi link prologKeywordIn        Statement
"    hi link prologClauseHead       Constant
    hi link prologQuestion         PreProc
    hi link prologSpecialCharacter Special
    hi link prologNumber           Number
    hi link prologAsIs             Normal
    hi link prologCommentError     Error
    hi link prologAtom             String
"    hi link prologParens           Normal
"    hi link prologDebugParensError Error
    hi link prologString           String
    hi link prologOperator         Operator

  endif

endif

let b:current_syntax = "DyLOG"

" vim: ts=28
